==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/admin/gm_emails.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	gm_emails.lang.inc.php 2015-04-13 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'GM_EMAILS_PREVIEW' => 'Das Speichern ist erst nach Aufruf der Vorschau möglich!',
	'GM_EMAILS_RESTORE_BACKUP' => 'Backup wiederherstellen',
	'GM_EMAILS_RESTORE_ORIGINAL' => 'Original wiederherstellen',
	'GM_EMAILS_SAVE' => 'Speichern',
	'GM_EMAILS_SAVE_BACKUP' => 'Backup der Vorlage erstellen',
	'gift_accepted' => 'Admin: Gutschein freigeschaltet',
	'send_coupon' => 'Admin: Coupon senden',
	'send_gift' => 'Admin: Gutschein senden',
	'delete_account_mail' => 'Admin: Kundenkonto löschen',
	'send_paylink' => 'Admin: PayPal-Link senden',
	'withdrawal_confirmation' => 'Widerrufssendebestätigung',
	'invoice_mail' => 'Rechnungsversand',
	'amazonadvpay_mail' => 'Bezahlen mit Amazon: Benachrichtigung über abgelehnte Zahlart',
	'amazonadvpay_mail_hard' => 'Bezahlen mit Amazon: Benachrichtigung über final abgelehnte Zahlart',
	'create_account_mail' => 'Kundenkonto erstellt',
	'new_password_mail' => 'Neues Passwort',
	'newsletter_mail' => 'Newsletter',
	'order_mail' => 'Bestellbestätigung',
	'password_verification_mail' => 'Passwortbestätigung',
	'send_gift_to_friend' => 'Gutschein',
	'change_order_mail' => 'Admin: Änderung Bestellstatus',
	'admin_create_account_mail' => 'Admin: Kundenkonto angelegt',
	'GM_EMAILS_TITLE' => 'Vorlagen',
	'GM_EMAILS_TYPE_HTML' => 'zur HTML Vorlage wechseln',
	'GM_EMAILS_TYPE_TXT' => 'zur Text Vorlage wechseln',
	'GM_ERROR_PERMISSION' => 'Speichern der E-Mail Vorlage fehlgeschlagen! Bitte kontrollieren Sie die Dateirechte (777).',
	'GM_LANGUAGE' => 'Sprache: ',
	'GM_PREVIEW' => 'Vorschau',
	'HEADING_SUB_TITLE' => 'Gambio',
	'HEADING_TITLE' => 'Vorlagen bearbeiten'
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/admin/gm_emails.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	gm_emails.lang.inc.php 2015-04-13 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'GM_EMAILS_PREVIEW' => 'Das Speichern ist erst nach Aufruf der Vorschau möglich!',
	'GM_EMAILS_RESTORE_BACKUP' => 'Backup wiederherstellen',
	'GM_EMAILS_RESTORE_ORIGINAL' => 'Original wiederherstellen',
	'GM_EMAILS_SAVE' => 'Speichern',
	'GM_EMAILS_SAVE_BACKUP' => 'Backup der Vorlage erstellen',
	'gift_accepted' => 'Admin: Gutschein freigeschaltet',
	'send_coupon' => 'Admin: Coupon senden',
	'send_gift' => 'Admin: Gutschein senden',
	'delete_account_mail' => 'Admin: Kundenkonto löschen',
	'send_paylink' => 'Admin: PayPal-Link senden',
	'withdrawal_confirmation' => 'Widerrufssendebestätigung',
	'invoice_mail' => 'Rechnungsversand',
	'amazonadvpay_mail' => 'Bezahlen mit Amazon: Benachrichtigung über abgelehnte Zahlart',
	'amazonadvpay_mail_hard' => 'Bezahlen mit Amazon: Benachrichtigung über final abgelehnte Zahlart',
	'create_account_mail' => 'Kundenkonto erstellt',
	'new_password_mail' => 'Neues Passwort',
	'newsletter_mail' => 'Newsletter',
	'order_mail' => 'Bestellbestätigung',
	'password_verification_mail' => 'Passwortbestätigung',
	'send_gift_to_friend' => 'Gutschein',
	'change_order_mail' => 'Admin: Änderung Bestellstatus',
	'admin_create_account_mail' => 'Admin: Kundenkonto angelegt',
	'GM_EMAILS_TITLE' => 'Vorlagen',
	'GM_EMAILS_TYPE_HTML' => 'zur HTML Vorlage wechseln',
	'GM_EMAILS_TYPE_TXT' => 'zur Text Vorlage wechseln',
	'GM_ERROR_PERMISSION' => 'Speichern der E-Mail Vorlage fehlgeschlagen! Bitte kontrolliere die Dateirechte (777).',
	'GM_LANGUAGE' => 'Sprache: ',
	'GM_PREVIEW' => 'Vorschau',
	'HEADING_SUB_TITLE' => 'Gambio',
	'HEADING_TITLE' => 'Vorlagen bearbeiten'
);
